package com.muyu.cloud.system.controller;

import com.muyu.cloud.system.domain.UserInfo;
import com.muyu.cloud.system.service.UserInfoService;
import com.muyu.common.result.Result;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @Author: DongZeLiang
 * @date: 2024/5/24
 * @Description: 用户信息控制层
 * @Version: 1.0
 */
@RestController
@AllArgsConstructor
@RequestMapping("/user-info")
public class UserInfoController {

    private final UserInfoService userInfoService;

    /**
     * 通过用户名称查询用户信息
     * @param userName 用户名称
     * @return 用户信息
     */
    @GetMapping("/by/user-name/{userName}")
    public Result<UserInfo> findByUserName(@PathVariable("userName") String userName) {
        return Result.success(userInfoService.selectByUserName(userName));
    }
}
