package com.muyu.cloud.system.mapper;

import com.muyu.cloud.system.domain.BookInfo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @Author: DongZeLiang
 * @date: 2024/5/23
 * @Description: 书籍持久层
 * @Version: 1.0
 */
@Mapper
public interface BookInfoMapper {

    /**
     * 添加数据
     * @param bookInfo 数据对象
     * @return 返回添加的自增ID
     */
    int insert(BookInfo bookInfo);


    /**
     * 通过书籍ID查询书籍信息
     * @param bookId 书籍ID
     * @return 数据信息
     */
    BookInfo selectByBookId(@Param("bookId") Integer bookId);

    /**
     * 通过书籍信息查询集合
     * @param bookInfo 数据信息
     * @return 符合集合内容
     */
    List<BookInfo> list(BookInfo bookInfo);

    /**
     * 通过ID修改书籍信息
     * @param bookInfo 数据信息
     * @return 修改条数
     */
    int updateByBookId(BookInfo bookInfo);

    /**
     * 通过书籍ID删除书籍信息
     * @param bookId 书籍ID
     * @return 返回删除条数
     */
    int deleteByBookId(@Param("bookId") Integer bookId);
}
